@@ -3,7 +3,7 @@ import operator
 import numbers
 import scipy.sparse as sparse
 from findiff.coefs import coefficients, coefficients_non_uni
-from .stencils import Stencil
+from .stencils import StencilSet
 from .utils import *
 from .grids import Grid
 
@@ -23,30 +23,13 @@ class BinaryOperator(Operator):
         self.right = right
 
     def apply(self, rhs, *args, **kwargs):
-
-        if isinstance(self.right, LinearMap) or isinstance(self.right, BinaryOperator):
-            right = self.right.apply(rhs, *args, **kwargs)
-        else:
-            right = self.right
-
-        if isinstance(self.left, LinearMap) or isinstance(self.left, BinaryOperator):
-            left = self.left.apply(right, *args, **kwargs)
-        else:
-            left = self.left
-
-        return self.oper(left, right)
+        raise NotImplementedError
 
     def __call__(self, rhs, *args, **kwargs):
         return self.apply(rhs, *args, **kwargs)
 
-    def set_accuracy(self, acc):
-        if isinstance(self.left, Operator):
-            self.left.set_accuracy(acc)
-        if isinstance(self.right, Operator):
-            self.right.set_accuracy(acc)
-
-    def stencil(self, shape, acc=None):
-        return Stencil(self, shape, acc=acc)
+    def stencil(self, shape):
+        return StencilSet(self, shape)
 
 
 class Plus(BinaryOperator):
@@ -91,12 +74,8 @@ class Plus(BinaryOperator):
         left, right = self.left, self.right
         if isinstance(self.left, Operator):
             left = self.left.matrix(shape, *args, **kwargs)
-        elif isinstance(self.left, np.ndarray):
-            left = sparse.diags(self.left.reshape(-1), 0)
         if isinstance(self.right, Operator):
             right = self.right.matrix(shape, *args, **kwargs)
-        elif isinstance(self.right, np.ndarray):
-            right = sparse.diags(self.right.reshape(-1), 0)
         return left + right
 
 
@@ -142,12 +121,8 @@ class Minus(BinaryOperator):
         left, right = self.left, self.right
         if isinstance(self.left, Operator):
             left = self.left.matrix(shape, *args, **kwargs)
-        elif isinstance(self.left, np.ndarray):
-            left = sparse.diags(self.left.reshape(-1), 0)
         if isinstance(self.right, Operator):
             right = self.right.matrix(shape, *args, **kwargs)
-        elif isinstance(self.right, np.ndarray):
-            right = sparse.diags(self.right.reshape(-1), 0)
         return left - right
 
 
@@ -277,10 +252,7 @@ class Diff(LinearMap):
         acc = DEFAULT_ACC
 
         def get_h(a):
-            if isinstance(a, Grid):
-                grid = a
-                h = grid.spacing(self.axis)
-            elif isinstance(a, dict):
+            if isinstance(a, dict):
                 h = a[self.axis]
             else:
                 h = a
@@ -433,9 +405,9 @@ class Diff(LinearMap):
             cd = coef_dicts[base_ind_short[self.axis]]
             cs, os = cd['coefficients'], cd['offsets']
             for c, o in zip(cs, os):
-                off_short = np.zeros(len(shape), dtype=np.int)
+                off_short = np.zeros(len(shape), dtype=int)
                 off_short[self.axis] = int(o)
-                off_ind_short = np.array(base_ind_short, dtype=np.int) + off_short
+                off_ind_short = np.array(base_ind_short, dtype=int) + off_short
                 off_long = long_inds[tuple(off_ind_short)]
 
                 mat[base_ind_long, off_long] += c
@@ -491,12 +463,6 @@ class Diff(LinearMap):
 
         return mat
 
-#    def stencil(self, shape, h=None, acc=None, old_stl=None):
-#        if isinstance(h, dict):
-#            h = h[self.axis]
-#        acc = self._properties(self.acc, acc, 2)
-#        return Stencil(shape, self.axis, self.order, h, acc, old_stl)
-
     def set_accuracy(self, acc):
         self.acc = acc
 
@@ -536,6 +502,7 @@ class Diff(LinearMap):
 
 
 class Id(LinearMap):
+    """ The identity operator. When applied to an array, returns the same array (not a copy) """
 
     def __init__(self):
         self.value = 1
@@ -544,6 +511,14 @@ class Id(LinearMap):
         return rhs
 
     def matrix(self, shape):
+        """ Matrix representation of the identity operator, i.e. identity matrix of given shape.
+
+        :param shape: Shape of the arrays to which Id shall be applied
+        :type shape: tuple of ints
+        :return: Sparse identity matrix.
+        :rtype: scipy.sparse.csr_matrix
+        """
+
         siz = np.prod(shape)
         mat = sparse.lil_matrix((siz, siz))
         diag = list(range(siz))
@@ -553,21 +528,18 @@ class Id(LinearMap):
 
 class Coef(object):
     """
-            Encapsulates a constant (number) or variable (N-dimensional coordinate array) value to multiply with a linear operator
+    Encapsulates a constant (number) or variable (N-dimensional coordinate array) value to multiply with a linear operator
 
-            :param value: a number or an numpy.ndarray with meshed coordinates
+    :param value: a number or an numpy.ndarray with meshed coordinates
 
-            ============
-            **Example**:
+    **Example**:
 
-               The following example defines the differential operator
+    The following example defines the differential operator
 
-               .. math::
+    .. math:: 2x\\frac{\\partial^3}{\\partial x^2\\partial z}
 
-                  2x \frac{\partial^3}{\partial x^2 \partial z}
-
-               >>> X, Y, Z, U = numpy.meshgrid(x, y, z, u, indexing="ij")
-               >>> diff_op = Coef(2*X) * FinDiff((0, dx, 2), (2, dz, 1))
+    >>> X, Y, Z, U = numpy.meshgrid(x, y, z, u, indexing="ij")
+    >>> diff_op = Coef(2*X) * FinDiff((0, dx, 2), (2, dz, 1))
 
     """
 
