@@ -8,8 +8,14 @@ class Grid(object):
 class UniformGrid(Grid):
 
     def __init__(self, shape, spac, center=None):
-        self.shape = shape
-        self.ndims = len(shape)
+
+        if not hasattr(shape, '__len__'):
+            self.shape = shape,
+            self.ndims = 1
+        else:
+            self.shape = shape
+            self.ndims = len(shape)
+
         if not hasattr(spac, '__len__'):
             self.spac = spac,
         else:
