@@ -1,6 +1,6 @@
 from .utils import *
 from .diff import Coef, Id, Diff, Plus, Minus, Mul, DEFAULT_ACC, LinearMap
-from .stencils import Stencil
+from .stencils import StencilSet
 
 
 class FinDiff(LinearMap):
@@ -37,7 +37,6 @@ class FinDiff(LinearMap):
 
             This class is actually deprecated and will be replaced by the Diff class in the future.
 
-        ============
         **Example**:
 
 
@@ -48,21 +47,21 @@ class FinDiff(LinearMap):
            >>> X, Y, Z = np.meshgrid(x, y, z, indexing='ij')
            >>> f = X**2 + Y**2 + Z**2
 
-           To create :math:`\frac{\partial f}{\partial x}` on a uniform grid with spacing dx, dy
+           To create :math:`\\frac{\\partial f}{\\partial x}` on a uniform grid with spacing dx, dy
            along the 0th axis or 1st axis, respectively, instantiate a FinDiff object and call it:
 
            >>> d_dx = FinDiff(0, dx)
            >>> d_dy = FinDiff(1, dx)
            >>> result = d_dx(f)
 
-           For :math:`\frac{\partial^2 f}{\partial x^2}` or :math:`\frac{\partial^2 f}{\partial y^2}`:
+           For :math:`\\frac{\\partial^2 f}{\\partial x^2}` or :math:`\\frac{\\partial^2 f}{\\partial y^2}`:
 
            >>> d2_dx2 = FinDiff(0, dx, 2)
            >>> d2_dy2 = FinDiff(1, dy, 2)
            >>> result_2 = d2_dx2(f)
            >>> result_3 = d2_dy2(f)
 
-           For :math:`\frac{\partial^4 f}{\partial x \partial^2 y \partial z}`, do:
+           For :math:`\\frac{\\partial^4 f}{\partial x \\partial^2 y \\partial z}`, do:
 
            >>> op = FinDiff((0, dx), (1, dy, 2), (2, dz))
            >>> result_4 = op(f)
@@ -94,10 +93,8 @@ class FinDiff(LinearMap):
                 args = self.coords,
         return self.pds(rhs, *args, **kwargs)
 
-    def stencil(self, shape, acc=None):
-        if acc is None and self.acc is not None:
-            acc = self.acc
-        return Stencil(self, shape, acc=acc)
+    def stencil(self, shape):
+        return StencilSet(self, shape)
 
     def matrix(self, shape, h=None, acc=None):
         if acc is None:
